-----------------------------------------------------------------------------------------------
-- Client Lua Script for QuestTrackerHide
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- QuestTrackerHide Module Definition
-----------------------------------------------------------------------------------------------
local QuestTrackerHide = {} 
---------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
local tDefaultUserSettings = {
	nOL = -27,
	nOT = -27,
	nOR = 27,
	nOB = 27,
	Fade = 0,
	Opacity = 1
}
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function QuestTrackerHide:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function QuestTrackerHide:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
	local QTHSFade = 0
	local QTHSOpacity = 1
end

function QuestTrackerHide:OnSave(eType)
	if eType ~= GameLib.CodeEnumAddonSaveLevel.Character then
		return nil
	end
	self.tUserSettings.Fade = QTHSFade
	self.tUserSettings.Opacity = QTHSOpacity
	self.tUserSettings.nOL, self.tUserSettings.nOT, self.tUserSettings.nOR, self.tUserSettings.nOB = self.wndMain:GetAnchorOffsets()	
	return self.tUserSettings
end

function QuestTrackerHide:OnRestore(eLevel,tSavedData)
	if tSavedData.nOL ~= nil and tSavedData.nOT ~= nil and tSavedData.nOR ~= nil and tSavedData.nOB ~= nil then
		self.tUserSettings = tSavedData		
	end
	QTHSOpacity = self.tUserSettings.Opacity
	QTHSFade = self.tUserSettings.Fade
end
-----------------------------------------------------------------------------------------------
-- QuestTrackerHide OnLoad
-----------------------------------------------------------------------------------------------
function QuestTrackerHide:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("QuestTrackerHide.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
		self.tUserSettings = {}
	for k, v in pairs(tDefaultUserSettings) do
		self.tUserSettings[k] = v
	end
end

-----------------------------------------------------------------------------------------------
-- QuestTrackerHide OnDocLoaded
-----------------------------------------------------------------------------------------------
function QuestTrackerHide:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "TheTopWindow", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(true, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("qth", "OnQuestTrackerHideOn", self)
		Apollo.RegisterSlashCommand("qthlock", "OnQuestTrackerHideLock", self)
		Apollo.RegisterSlashCommand("qthunlock", "OnQuestTrackerHideUnlock", self)
		Apollo.RegisterSlashCommand("qthopacity", "OnQuestTrackerHideOpacity", self)
		Apollo.RegisterSlashCommand("qthfade", "OnQuestTrackerHideFade", self)
		Apollo.RegisterSlashCommand("qthnofade", "OnQuestTrackerHideNoFade", self)
		Apollo.RegisterSlashCommand("qthspecial", "OnQuestTrackerHideSpecial", self)

		QTH = nil
		QTHVis = true
		self.wndMain:SetAnchorOffsets(self.tUserSettings.nOL, self.tUserSettings.nOT, self.tUserSettings.nOR, self.tUserSettings.nOB)
		self.wndMain:SetOpacity(self.tUserSettings.Opacity, 1)
		self.wndMain:SetStyle("AutoFade", self.tUserSettings.Fade)
		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- QuestTrackerHide Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/qth"
function QuestTrackerHide:OnQuestTrackerHideOn()
	if QTHVis == true then
		QTHVis = false
	else QTHVis = true
	end
	self.wndMain:Show(QTHVis)
end
function QuestTrackerHide:OnQuestTrackerHideLock()
	self.wndMain:SetStyle("Moveable", false)
	self.wndMain:SetStyle("IgnoreMouse", true)
	self.wndMain:SetSprite("")
end
function QuestTrackerHide:OnQuestTrackerHideUnlock()
	self.wndMain:SetStyle("Moveable", true)
	self.wndMain:SetStyle("Picture", true)
	self.wndMain:SetStyle("IgnoreMouse", false)
	self.wndMain:SetSprite("AbilitiesSprites:spr_StatVertProgBase")
end
function QuestTrackerHide:OnQuestTrackerHideOpacity(strCmd,strArg)
	self.wndMain:SetOpacity(strArg,1)
	QTHSOpacity = strArg
end
function QuestTrackerHide:OnQuestTrackerHideFade()
	self.wndMain:SetStyle("AutoFade", true)
	self.wndMain:SetOpacity(self.tUserSettings.Opacity, 1)
	QTHSFade = true
end
function QuestTrackerHide:OnQuestTrackerHideNoFade()
	self.wndMain:SetOpacity(self.tUserSettings.Opacity, 1)
	self.wndMain:SetStyle("AutoFade", false)
	QTHSFade = false
end
function QuestTrackerHide:OnQuestTrackerHideSpecial()
	Print("You're a beautiful, special person. Thank you for using this addon. Have fun in Nexus with a little less screen clutter!")
end
-----------------------------------------------------------------------------------------------
-- QuestTrackerHideForm Functions
-----------------------------------------------------------------------------------------------
-- when the OK button is clicked
function QuestTrackerHide:OnOK()
	self.wndMain:Close() -- hide the window
end
	
function QuestTrackerHide:OnTheButtonClick()
	if QTH == nil then
		QTH = false 
	elseif QTH == true then
		QTH = false 
	else QTH = true 
	end
	Apollo.GetAddon("QuestTracker").wndMain:FindChild("QuestTrackerScroll"):Show(QTH)
end

-- when the Cancel button is clicked
function QuestTrackerHide:OnCancel()
	self.wndMain:Close() -- hide the window
end

-------------------------------------------------------------------------------------
-- QuestTrackerHide Instance
-----------------------------------------------------------------------------------------------
local QuestTrackerHideInst = QuestTrackerHide:new()
QuestTrackerHideInst:Init()
